@@ -1,4 +1,4 @@
-from pyunity import SceneManager, GameObject, Vector3, MeshRenderer, Mesh, Color, AABBoxCollider, Rigidbody, Material
+from pyunity import SceneManager, GameObject, Vector3, MeshRenderer, Mesh, RGB, AABBoxCollider, Rigidbody, Material
 
 def main():
     scene = SceneManager.AddScene("Scene")
@@ -10,7 +10,7 @@ def main():
     cube.transform.localPosition = Vector3(2, 0, 0)
     renderer = cube.AddComponent(MeshRenderer)
     renderer.mesh = Mesh.cube(2)
-    renderer.mat = Material(Color(255, 0, 0))
+    renderer.mat = Material(RGB(255, 0, 0))
     collider = cube.AddComponent(AABBoxCollider)
     collider.SetSize(Vector3(1, -1, -1), Vector3(3, 1, 1))
     rb = cube.AddComponent(Rigidbody)
@@ -23,7 +23,7 @@ def main():
     cube.transform.localPosition = Vector3(5, 0, 0)
     renderer = cube.AddComponent(MeshRenderer)
     renderer.mesh = Mesh.cube(2)
-    renderer.mat = Material(Color(0, 0, 255))
+    renderer.mat = Material(RGB(0, 0, 255))
     collider = cube.AddComponent(AABBoxCollider)
     collider.SetSize(Vector3(4, -1, -1), Vector3(6, 1, 1))
     rb = cube.AddComponent(Rigidbody)
@@ -34,6 +34,5 @@ def main():
 
     SceneManager.LoadScene(scene)
 
-
 if __name__ == "__main__":
     main()
