@@ -5,7 +5,7 @@ Engine itself. Only supports
 non-rotated colliders.
 
 To create an immoveable object, use
-math.inf or the provided ``infinity``
+math.inf or the provided :const:`Infinity`
 variable. This will make the object
 not be able to move, unless you set
 an initial velocity. Then, the
@@ -31,11 +31,12 @@ the config file like so:
 Inside the config file there are some configurations:
 
 - ``gravity`` is the gravity of the whole system. It only
-  affects Rigidbodies that have ``Rigidbody.gravity`` set to True.
+  affects Rigidbodies that have :attr:`Rigidbody.gravity` set to True.
 
 """
 
 from .core import *
 from . import core
+
 __all__ = []
 __all__.extend(core.__all__)
