@@ -25,35 +25,42 @@ pull request.
 
 """
 
+__all__ = ["GetWindowProvider", "SetWindowProvider",
+           "CustomWindowProvider", "ABCWindow"]
+
 from ..errors import *
 from .. import Logger
 from .. import config
+from .. import settings
+from ..values import ABCMeta, abstractmethod
 import os
-import pkgutil
-import importlib
+import sys
+import importlib.util
 
-def checkModule(module):
+def checkModule(name):
     if os.getenv("PYUNITY_TESTING") is not None:
-        return
-    if not pkgutil.find_loader(module):
-        raise Exception
+        return sys.modules[name]
+    spec = importlib.util.find_spec(name)
+    if spec is None:
+        raise PyUnityException
+    module = importlib.util.module_from_spec(spec)
+    spec.loader.exec_module(module)
+    sys.modules[name] = module
+    return module
 
 def glfwCheck():
     """Checks to see if GLFW works"""
-    checkModule("glfw")
-    import glfw
+    glfw = checkModule("glfw")
     if not glfw.init():
-        raise Exception
-    glfw.create_window(5, 5, "a", None, None)
-    glfw.terminate()
+        raise PyUnityException
+    window = glfw.create_window(5, 5, "test", None, None)
+    glfw.destroy_window(window)
 
 def sdl2Check():
     """Checks to see if PySDL2 works"""
-    if not pkgutil.find_loader("sdl2"):
-        raise Exception
-    import sdl2
+    sdl2 = checkModule("sdl2")
     if sdl2.SDL_Init(sdl2.SDL_INIT_VIDEO) != 0:
-        raise Exception
+        raise PyUnityException
 
 def glutCheck():
     """Checks to see if GLUT works"""
@@ -61,7 +68,6 @@ def glutCheck():
     import OpenGL.GLUT
     OpenGL.GLUT.glutInit()
 
-
 providers = {
     "GLFW": ("glfwWindow", glfwCheck),
     "PySDL2": ("sdl2Window", sdl2Check),
@@ -70,6 +76,21 @@ providers = {
 
 def GetWindowProvider():
     """Gets an appropriate window provider to use"""
+    if "window_provider" in settings.db:
+        env = os.getenv("PYUNITY_WINDOW_PROVIDER")
+        if env is not None:
+            env = env.split(",")
+            use = env[0] == settings.db["window_provider"]
+        else:
+            use = True
+        if use:
+            if "window_cache" in settings.db:
+                del settings.db["window_cache"]
+            Logger.LogLine(Logger.DEBUG, "Detected settings.json entry")
+            windowProvider = settings.db["window_provider"]
+            Logger.LogLine(
+                Logger.DEBUG, "Using window provider", windowProvider)
+            return importlib.import_module(f".{providers[windowProvider][0]}", __name__)
 
     windowProvider = ""
     i = 0
@@ -79,6 +100,8 @@ def GetWindowProvider():
         env = env.split(",")
         for specified in reversed(env):
             if specified not in providers:
+                Logger.LogLine(Logger.WARN, "PYUNITY_WINDOW_PROVIDER environment variable contains",
+                               specified, "but there is no window provider called that")
                 continue
             for item in winfo:
                 if item[0] == specified:
@@ -93,6 +116,7 @@ def GetWindowProvider():
             checker()
             windowProvider = name
         except Exception as e:
+            print(e)
             if next is not None:
                 Logger.LogLine(Logger.DEBUG, name,
                                "doesn't work, trying", next)
@@ -103,24 +127,54 @@ def GetWindowProvider():
             break
         i += 1
 
-    if os.environ["PYUNITY_DEBUG_MODE"] == "1":
-        Logger.LogLine(Logger.DEBUG, "Using window provider", windowProvider)
-
-    return importlib.import_module("." + providers[windowProvider][0], __name__)
+    settings.db["window_provider"] = windowProvider
+    settings.db["window_cache"] = True
+    Logger.LogLine(Logger.DEBUG, "Using window provider", windowProvider)
+    return importlib.import_module(f".{providers[windowProvider][0]}", __name__)
 
 def SetWindowProvider(name):
     if name not in providers:
         raise PyUnityException(
-            "No window provider named " + repr(name) + " found")
+            f"No window provider named {name!r} found")
     module, checker = providers[name]
-    windowProvider = None
+    exc = None
     try:
         checker()
-        windowProvider = name
     except Exception as e:
-        pass
-    if windowProvider is None:
-        raise PyUnityException("Cannot use window provider " + repr(name))
-    window = importlib.import_module("." + module, __name__)
+        exc = e
+    if exc is not None:
+        raise PyUnityException(f"Cannot use window provider {name!r}")
+    Logger.LogLine(Logger.DEBUG, "Using window provider", name)
+    window = importlib.import_module(f".{module}", __name__)
     config.windowProvider = window
     return window
+
+def CustomWindowProvider(cls):
+    Logger.LogLine(Logger.DEBUG, "Using window provider", cls.__name__)
+    config.windowProvider = cls
+    return cls
+
+class ABCWindow(metaclass=ABCMeta):
+    @abstractmethod
+    def __init__(self, name, resize):
+        pass
+
+    @abstractmethod
+    def get_mouse(self, mousecode, keystate):
+        pass
+
+    @abstractmethod
+    def get_key(self, keycode, keystate):
+        pass
+
+    @abstractmethod
+    def get_mouse_pos(self):
+        pass
+
+    @abstractmethod
+    def quit(self):
+        pass
+
+    @abstractmethod
+    def start(self, update_func):
+        pass
